@@ -148,11 +148,6 @@ indicator_button_box_finalize (GObject *object)
 
   indicator_button_box_disconnect_signals (box);
 
-  if (box->label != NULL)
-    g_object_unref (G_OBJECT (box->label));
-  if (box->icon != NULL)
-    g_object_unref (G_OBJECT (box->icon));
-
   G_OBJECT_CLASS (indicator_button_box_parent_class)->finalize (object);
 }
 
@@ -222,6 +217,8 @@ indicator_button_box_label_changed (GtkLabel            *label,
   g_return_if_fail (XFCE_IS_INDICATOR_BUTTON_BOX (box));
   g_return_if_fail (GTK_IS_LABEL (label));
 
+  box->cached = FALSE;
+
   gtk_widget_queue_resize (GTK_WIDGET (box));
 }
 
@@ -235,18 +232,17 @@ indicator_button_box_set_label (IndicatorButtonBox  *box,
   g_return_if_fail (GTK_IS_LABEL (label));
 
   if (box->label != NULL)
-    {
-      gtk_container_remove (GTK_CONTAINER (box), box->label);
-      g_object_unref (G_OBJECT (box->label));
-    }
+    gtk_container_remove (GTK_CONTAINER (box), box->label);
   box->label = GTK_WIDGET (label);
-  g_object_ref (G_OBJECT (box->label));
   g_signal_connect(G_OBJECT(box->label), "notify::label",
                    G_CALLBACK(indicator_button_box_label_changed), box);
+  g_signal_connect(G_OBJECT(box->label), "notify::visible",
+                   G_CALLBACK(indicator_button_box_label_changed), box);
 
-  gtk_label_set_ellipsize (GTK_LABEL (box->label), PANGO_ELLIPSIZE_END);
   box->is_small = FALSE;
 
+  box->cached = FALSE;
+
   gtk_container_add (GTK_CONTAINER (box), box->label);
   gtk_widget_show (box->label);
 }
@@ -279,19 +275,9 @@ indicator_button_box_set_image (IndicatorButtonBox  *box,
   /* g_debug ("indicator-button-box set image, image=%x", (uint) image); */
 
   if (box->icon != NULL)
-    {
-      gtk_container_remove (GTK_CONTAINER (box), box->icon);
-      g_object_unref (G_OBJECT (box->icon));
-    }
-
-  if(gtk_image_get_storage_type(image) == GTK_IMAGE_EMPTY)
-    {
-      box->icon = NULL;
-      return;
-    }
+    gtk_container_remove (GTK_CONTAINER (box), box->icon);
 
   box->icon = GTK_WIDGET (image);
-  g_object_ref (G_OBJECT (box->icon));
   g_signal_connect(G_OBJECT(box->icon), "notify::pixbuf",
                    G_CALLBACK(indicator_button_box_icon_changed), box);
 
@@ -362,7 +348,9 @@ indicator_button_box_is_small (IndicatorButtonBox *box)
 
   box->orientation = indicator_config_get_panel_orientation (box->config);
 
-  if (box->label != NULL)
+  if (box->label != NULL &&
+      gtk_widget_get_visible (box->label) &&
+      g_strcmp0 (gtk_label_get_label (GTK_LABEL (box->label)), "") != 0)
     {
       box->is_small = FALSE;
       if (box->orientation == GTK_ORIENTATION_VERTICAL &&
@@ -371,10 +359,12 @@ indicator_button_box_is_small (IndicatorButtonBox *box)
 	{
 	  box->orientation = GTK_ORIENTATION_HORIZONTAL;
 	  gtk_misc_set_alignment (GTK_MISC (box->label), 0.0, 0.5);
+	  gtk_label_set_ellipsize (GTK_LABEL (box->label), PANGO_ELLIPSIZE_END);
 	}
       else
 	{
 	  gtk_misc_set_alignment (GTK_MISC (box->label), 0.5, 0.5);
+	  gtk_label_set_ellipsize (GTK_LABEL (box->label), PANGO_ELLIPSIZE_NONE);
 	}
       gtk_label_set_angle (GTK_LABEL (box->label),
 			   (indicator_config_get_orientation (box->config) == GTK_ORIENTATION_VERTICAL) ?
@@ -420,7 +410,9 @@ indicator_button_box_get_preferred_width (GtkWidget *widget,
     {
       gtk_widget_get_preferred_width (box->label, &min_size, &nat_size);
 
-      if (box->icon != NULL && box->orientation == GTK_ORIENTATION_HORIZONTAL)
+      if (box->icon != NULL &&
+          gtk_image_get_storage_type (GTK_IMAGE (box->icon)) != GTK_IMAGE_EMPTY &&
+          box->orientation == GTK_ORIENTATION_HORIZONTAL)
         {
           min_size = min_size + ICON_SIZE + SPACING;
           nat_size = nat_size + ICON_SIZE + SPACING;
@@ -473,7 +465,9 @@ indicator_button_box_get_preferred_height (GtkWidget *widget,
     {
       gtk_widget_get_preferred_height (box->label, &min_size, &nat_size);
 
-      if (box->icon != NULL && box->orientation == GTK_ORIENTATION_VERTICAL)
+      if (box->icon != NULL &&
+          gtk_image_get_storage_type (GTK_IMAGE (box->icon)) != GTK_IMAGE_EMPTY &&
+          box->orientation == GTK_ORIENTATION_VERTICAL)
         {
           min_size = min_size + ICON_SIZE + SPACING;
           nat_size = nat_size + ICON_SIZE + SPACING;
@@ -527,7 +521,10 @@ indicator_button_box_size_allocate (GtkWidget     *widget,
 
   indicator_button_box_is_small (box); // refresh cache
 
-  if (box->icon != NULL && box->label != NULL)
+  if (box->icon != NULL &&
+      gtk_image_get_storage_type (GTK_IMAGE (box->icon)) != GTK_IMAGE_EMPTY &&
+      box->label != NULL &&
+      !box->is_small)
     {
       if (box->orientation == GTK_ORIENTATION_HORIZONTAL)
         {
@@ -544,7 +541,8 @@ indicator_button_box_size_allocate (GtkWidget     *widget,
       gtk_widget_size_allocate (box->icon, &icon_alloc);
       gtk_widget_size_allocate (box->label, &label_alloc);
     }
-  else if (box->icon != NULL)
+  else if (box->icon != NULL &&
+           gtk_image_get_storage_type (GTK_IMAGE (box->icon)) != GTK_IMAGE_EMPTY)
     {
       gtk_widget_size_allocate (box->icon, &icon_alloc);
     }
